@@ -1,21 +1,19 @@
 require(DoE.wrapper)
 options(warn=-1)
-if(getRversion() >= "3.6.0") RNGkind(sample.kind="Rounding")
-options(warn=0)
 
 set.seed(1212)
 ## test utility functions from DoE.base for designs that are not in
 ## DoE.base
 
 plan <- bbd.design(3)
-y <- rnorm(nrow(plan))
+y <- round(rnorm(nrow(plan)), 4)
 lm(y~., plan)
 lm(y~., qua.design(plan))
 lm(y~., qua.design(plan, quantitative="none",
       contrasts=c(A="contr.treatment",B="contr.treatment",C="contr.treatment")))
 
 plan <- ccd.design(4)
-y <- rnorm(nrow(plan))
+y <- round(rnorm(nrow(plan)), 4)
 lm(y~., plan)
 lm(y~., qua.design(plan))
 lm(y~., qua.design(plan, quantitative="none",
@@ -23,7 +21,7 @@ lm(y~., qua.design(plan, quantitative="none",
             X3="contr.treatment",X4="contr.helmert")))
 
 plan <- FrF2(16,4,blocks=2)
-y <- rnorm(nrow(plan))
+y <- round(rnorm(nrow(plan)), 4)
 lm(y~., plan)
 lm(y~., qua.design(plan))
 lm(y~., qua.design(plan, quantitative="none",
